@@ -14,13 +14,13 @@ from .featurewiz import FE_remove_variables_using_SULOV_method, classify_feature
 from .featurewiz import classify_columns,FE_combine_rare_categories
 from .featurewiz import FE_count_rows_for_all_columns_by_group
 from .featurewiz import FE_add_age_by_date_col, FE_split_add_column, FE_get_latest_values_based_on_date_column
-from .featurewiz import FE_capping_outliers_beyond_IQR_Range, My_LabelEncoder, My_Groupby_Encoder
+from .featurewiz import FE_capping_outliers_beyond_IQR_Range, My_Groupby_Encoder
 from .featurewiz import EDA_classify_and_return_cols_by_type, EDA_classify_features_for_deep_learning
 from .featurewiz import FE_create_categorical_feature_crosses, EDA_find_skewed_variables
 from .featurewiz import FE_kmeans_resampler, FE_find_and_cap_outliers, EDA_find_outliers
 from .featurewiz import split_data_n_ways, FE_concatenate_multiple_columns
-from .featurewiz import simple_XGBoost_model, FE_discretize_numeric_variables, data_transform
-from .featurewiz import simple_LightGBM_model, complex_XGBoost_model, complex_LightGBM_model
+from .featurewiz import FE_discretize_numeric_variables
+from .ml_models import simple_XGBoost_model, simple_LightGBM_model, complex_XGBoost_model, complex_LightGBM_model,data_transform,My_LabelEncoder
 from .featurewiz import FE_transform_numeric_columns, FE_create_interaction_vars
 from .stacking_models import Stacking_Classifier, Blending_Regressor
 from .featurewiz import EDA_binning_numeric_column_displaying_bins, FE_add_lagged_targets_by_date_category
@@ -35,7 +35,7 @@ version_number = __version__
 print("""%s DASK version = %s. nrows=None uses all rows. Set nrows=1000 to randomly sample fewer rows.
 output = featurewiz(dataname, target, corr_limit=0.70, verbose=2, sep=',', 
 		header=0, test_data='',feature_engg='', category_encoders='',
-		dask_xgboost_flag=True, nrows=None)
+		dask_xgboost_flag=False, nrows=None)
 Create new features via 'feature_engg' flag : ['interactions','groupby','target']
                                 """ %(module_type, version_number))
 ################################################################################
